@@ -1,7 +1,8 @@
 core_get_package_function <- function(packageName, functionName) {
   if (packageName %in% rownames(installed.packages()) &&
-      exists(functionName, envir = asNamespace(packageName)))
+    exists(functionName, envir = asNamespace(packageName))) {
     get(functionName, envir = asNamespace(packageName))
-  else
+  } else {
     NULL
+  }
 }
