@@ -32,7 +32,7 @@ translate_formula <- function(f) {
       as.character(vars)
     }
   )
-  body_sql <- dbplyr::translate_sql_(list(f[[2]]), con = dbplyr::simulate_dbi())
+  body_sql <- dbplyr::translate_sql(!!f[[2]])
   lambda <- dbplyr::sql(paste(params_sql, "->", body_sql))
 
   lambda
@@ -82,7 +82,7 @@ process_dest_col <- function(expr, dest_col) {
 #' @param params Parameter(s) of the lambda expression, can be either a single
 #'   parameter or a comma separated listed of parameters in the form of
 #'   \code{.(param1, param2, ... )} (see examples)
-#' @param body Body of the lambda expression, *must be within parentheses*
+#' @param ... Body of the lambda expression, *must be within parentheses*
 #'
 #' @examples
 #' \dontrun{
@@ -92,7 +92,7 @@ process_dest_col <- function(expr, dest_col) {
 #' .(a, b) %->% (a < 1 && b > 1) # translates to <SQL> `a`,`b` -> (`a` < 1.0 AND `b` > 1.0)
 #' }
 #' @export
-`%->%` <- function(params, body) {
+`%->%` <- function(params, ...) {
   `.` <- function(...) {
     rlang::ensyms(...) %>%
       lapply(as.character) %>>%
@@ -115,10 +115,7 @@ process_dest_col <- function(expr, dest_col) {
     c(sep = ",") %>%
     do.call(paste, .)
 
-  body_sql <- dbplyr::translate_sql_(
-    rlang::enexprs(body),
-    con = dbplyr::simulate_dbi()
-  )
+  body_sql <- dbplyr::translate_sql(...)
 
   lambda <- dbplyr::sql(paste(params_sql, "->", body_sql))
   class(lambda) <- c(class(lambda), "spark_sql_lambda")
